#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-HZ2ScDZvstLCEFZ8XHdLyS
key:                  dhall-1.42.3-HZ2ScDZvstLCEFZ8XHdLyS
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  3d40b32443d0a07be9af84d6c322284e
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-HZ2ScDZvstLCEFZ8XHdLyS
depends:
    Diff-1.0-3AwBz9GmeQV7A6ZW8hzFS2
    aeson-2.2.2.0-GWc1LmCE0o9Bpe9MYCbSNj
    aeson-pretty-0.8.11-KuUwcRlHmdmISedWOJw1IX
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8
    atomic-write-0.2.1.1-Gdhjs86qH4q3PN2t57Mtvg base-4.18.2.1
    base16-bytestring-1.0.2.0-LgOviYpROdp3pOaaXE89pJ
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-49gRYT0muxnE6KNMA9p3wB
    cborg-0.2.10.0-EkqI8Afme1cCYVt6VfSnkd
    cborg-json-0.2.6.0-85wEQPLS9MBcgS8oLX5wd containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-LCpYZecH1in2oQEsdqMs5K
    data-fix-0.3.4-FJwN3N3t7Me5KMICtMv2t5 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-HICE9J8XcQOFvn2pSAA4Ue exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-1jb8W5zdFYII0rVJBsi5Yi
    hashable-1.4.7.0-FDr33SOXd6ZL3RCqzuvond haskeline-0.8.2.1
    http-client-0.7.19-CdoyGBdmx4CJG3r6obV7W1
    http-client-tls-0.3.6.4-AnHGLSahOg9HVl4h6a2CCE
    http-types-0.12.4-7VF1fWYoZaw5btElYXN8F2
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    megaparsec-9.7.1-1lcjkGjwJLg1AqlOPXLgZs
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-GaZ2e74kZTJHR0YFZY0APg
    optparse-applicative-0.18.1.0-1ZOUgEBAg4Z36ZcICQWhpn
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-JZyCKdHBFjE7RnIrVwVb0z
    pretty-simple-4.1.4.0-LsXIzQYljGVDRbNVskAirm
    prettyprinter-1.7.2-y57O1yX0U1K0S9aBMDJoK
    prettyprinter-ansi-terminal-1.1.4-6VAYBS49qMl9dVuVZ4ho8E
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-FvkfJpjQ1EnI6C5SdRdzp9
    serialise-0.2.6.1-3O617OyIhXlHEZa4fdJopC template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-C9wUaBH42xwFhwkrRmhUdp
    text-short-0.1.6.1-7JLn5dCMlWnFOXT3MS6FwH
    th-lift-instances-0.1.20-HD4qXDVAITD5yLkpplt8fZ time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-Ihfe6doCANm1TVMx2D80dC
    unordered-containers-0.2.21-A5j6YbVJ6iQ4Gx0hziy0Dr
    vector-0.13.2.0-HIEoUaJKlQrG3qeQBTxJjw

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

